@@ -4,7 +4,7 @@
 modname = 'card'
 distname = 'cubicweb-card'
 
-numversion = (0, 3, 0)
+numversion = (0, 4, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -19,8 +19,13 @@ classifiers = [
            'Programming Language :: JavaScript',
 ]
 
-__depends__ = {'cubicweb': '>= 3.9.0'}
-__recommends__ = {'cubicweb-preview': None}
+__depends__ = {
+    'cubicweb': '>= 3.15.0'
+    }
+__recommends__ = {
+    'cubicweb-preview': None,
+    'cubicweb-seo': None,
+    }
 
 # packaging ###
 
