@@ -7,7 +7,7 @@ class Card(AnyEntity):
     __regid__ = 'Card'
     rest_attr = 'wikiid'
 
-    fetch_attrs, fetch_order = fetch_config(['title'])
+    fetch_attrs, cw_fetch_order = fetch_config(['title'])
 
     def dc_title(self):
         return self.title
